
# THIS FILE IS GENERATED FROM OASYS SETUP.PY
short_version = '1.2.85'
version = '1.2.85'
full_version = '1.2.85'
git_revision = '52074a4f09dd32344341877eedbabd1b174c9d58'
release = True

if not release:
    version = full_version
    short_version += ".dev"
